@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::DDG::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::DDG::VERSION = '0.100';
+  $App::DuckPAN::DDG::VERSION = '0.101';
 }
 # ABSTRACT: DDG related functionality of duckpan
 
@@ -13,6 +13,18 @@ with 'App::DuckPAN::HasApp';
 use Module::Pluggable::Object;
 use Class::Load ':all';
 
+sub get_dukgo_user_pass {
+	my ( $self ) = @_;
+	my $config = $self->app->perl->get_dzil_config;
+	unless (defined $config->{'%DUKGO'}) {
+		shift->app->print_text(
+			"[ERROR] No configuration found for your https://dukgo.com/ username and password, please use: 'dzil setup' first!",
+		);
+		exit 1;
+	}
+	return $config->{'%DUKGO'}->{username}, $config->{'%DUKGO'}->{password};
+}
+
 sub get_blocks_from_current_dir {
 	my ( $self, @args ) = @_;
 	unless ($self->app->get_local_ddg_version) {
@@ -76,7 +88,7 @@ App::DuckPAN::DDG - DDG related functionality of duckpan
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 AUTHOR
 
